@@ -17,6 +17,9 @@ die "must pass a --field=INFO_FIELD[,OTHER FIELD] argument (e.g status)" unless
 
 my @fields=split /,/, $field;
 foreach (@ARGV){
+  if(/^all$/i){
+    my @tmp=
+  }
   my %h=$sbs->job_info(id=>$_);
   print $h{id};
   print "\t$h{$_}" foreach (@fields);
