@@ -5,10 +5,11 @@ use BatchSystem::SBS::ScriptsCommon;
 BatchSystem::SBS::ScriptsCommon::init();
 
 use Getopt::Long;
-my(@command, $chainCommands, $queue, $title);
+my(@command, $chainCommands, $queue, $title, $onfinished);
 if (!GetOptions(
 		"command=s"=>\@command,
 		"chain"=>\$chainCommands,
+		"onfinished=s"=>\$onfinished,
 		"queue=s"=>\$queue,
 		"title=s"=>\$title,
 	       )
@@ -24,7 +25,7 @@ foreach(@command){
     $id=$sbs->job_submit(command=>$_, queue=>$queue, title=>$title, on_finished=>$ids[-1]);
     print {*BatchSystem::SBS::STDLOG} info=> "chaining [$ids[-1]](on_finished)->[$id]";
   }else{
-    $id=$sbs->job_submit(command=>$_, queue=>$queue, title=>$title);
+    $id=$sbs->job_submit(command=>$_, queue=>$queue, title=>$title, on_finished=>$onfinished);
   }
   push @ids, $id;
 }
